# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from voltha_protos import common_pb2 as voltha__protos_dot_common__pb2
from voltha_protos import ext_config_pb2 as voltha__protos_dot_ext__config__pb2
from voltha_protos import extensions_pb2 as voltha__protos_dot_extensions__pb2
from voltha_protos import openolt_pb2 as voltha__protos_dot_openolt__pb2
from voltha_protos import tech_profile_pb2 as voltha__protos_dot_tech__profile__pb2


class OpenoltStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.DisableOlt = channel.unary_unary(
                '/openolt.Openolt/DisableOlt',
                request_serializer=voltha__protos_dot_openolt__pb2.Empty.SerializeToString,
                response_deserializer=voltha__protos_dot_openolt__pb2.Empty.FromString,
                )
        self.ReenableOlt = channel.unary_unary(
                '/openolt.Openolt/ReenableOlt',
                request_serializer=voltha__protos_dot_openolt__pb2.Empty.SerializeToString,
                response_deserializer=voltha__protos_dot_openolt__pb2.Empty.FromString,
                )
        self.ActivateOnu = channel.unary_unary(
                '/openolt.Openolt/ActivateOnu',
                request_serializer=voltha__protos_dot_openolt__pb2.Onu.SerializeToString,
                response_deserializer=voltha__protos_dot_openolt__pb2.Empty.FromString,
                )
        self.DeactivateOnu = channel.unary_unary(
                '/openolt.Openolt/DeactivateOnu',
                request_serializer=voltha__protos_dot_openolt__pb2.Onu.SerializeToString,
                response_deserializer=voltha__protos_dot_openolt__pb2.Empty.FromString,
                )
        self.DeleteOnu = channel.unary_unary(
                '/openolt.Openolt/DeleteOnu',
                request_serializer=voltha__protos_dot_openolt__pb2.Onu.SerializeToString,
                response_deserializer=voltha__protos_dot_openolt__pb2.Empty.FromString,
                )
        self.OmciMsgOut = channel.unary_unary(
                '/openolt.Openolt/OmciMsgOut',
                request_serializer=voltha__protos_dot_openolt__pb2.OmciMsg.SerializeToString,
                response_deserializer=voltha__protos_dot_openolt__pb2.Empty.FromString,
                )
        self.OnuPacketOut = channel.unary_unary(
                '/openolt.Openolt/OnuPacketOut',
                request_serializer=voltha__protos_dot_openolt__pb2.OnuPacket.SerializeToString,
                response_deserializer=voltha__protos_dot_openolt__pb2.Empty.FromString,
                )
        self.UplinkPacketOut = channel.unary_unary(
                '/openolt.Openolt/UplinkPacketOut',
                request_serializer=voltha__protos_dot_openolt__pb2.UplinkPacket.SerializeToString,
                response_deserializer=voltha__protos_dot_openolt__pb2.Empty.FromString,
                )
        self.FlowAdd = channel.unary_unary(
                '/openolt.Openolt/FlowAdd',
                request_serializer=voltha__protos_dot_openolt__pb2.Flow.SerializeToString,
                response_deserializer=voltha__protos_dot_openolt__pb2.Empty.FromString,
                )
        self.FlowRemove = channel.unary_unary(
                '/openolt.Openolt/FlowRemove',
                request_serializer=voltha__protos_dot_openolt__pb2.Flow.SerializeToString,
                response_deserializer=voltha__protos_dot_openolt__pb2.Empty.FromString,
                )
        self.HeartbeatCheck = channel.unary_unary(
                '/openolt.Openolt/HeartbeatCheck',
                request_serializer=voltha__protos_dot_openolt__pb2.Empty.SerializeToString,
                response_deserializer=voltha__protos_dot_openolt__pb2.Heartbeat.FromString,
                )
        self.EnablePonIf = channel.unary_unary(
                '/openolt.Openolt/EnablePonIf',
                request_serializer=voltha__protos_dot_openolt__pb2.Interface.SerializeToString,
                response_deserializer=voltha__protos_dot_openolt__pb2.Empty.FromString,
                )
        self.DisablePonIf = channel.unary_unary(
                '/openolt.Openolt/DisablePonIf',
                request_serializer=voltha__protos_dot_openolt__pb2.Interface.SerializeToString,
                response_deserializer=voltha__protos_dot_openolt__pb2.Empty.FromString,
                )
        self.GetDeviceInfo = channel.unary_unary(
                '/openolt.Openolt/GetDeviceInfo',
                request_serializer=voltha__protos_dot_openolt__pb2.Empty.SerializeToString,
                response_deserializer=voltha__protos_dot_openolt__pb2.DeviceInfo.FromString,
                )
        self.Reboot = channel.unary_unary(
                '/openolt.Openolt/Reboot',
                request_serializer=voltha__protos_dot_openolt__pb2.Empty.SerializeToString,
                response_deserializer=voltha__protos_dot_openolt__pb2.Empty.FromString,
                )
        self.CollectStatistics = channel.unary_unary(
                '/openolt.Openolt/CollectStatistics',
                request_serializer=voltha__protos_dot_openolt__pb2.Empty.SerializeToString,
                response_deserializer=voltha__protos_dot_openolt__pb2.Empty.FromString,
                )
        self.GetOnuStatistics = channel.unary_unary(
                '/openolt.Openolt/GetOnuStatistics',
                request_serializer=voltha__protos_dot_openolt__pb2.Onu.SerializeToString,
                response_deserializer=voltha__protos_dot_openolt__pb2.OnuStatistics.FromString,
                )
        self.GetGemPortStatistics = channel.unary_unary(
                '/openolt.Openolt/GetGemPortStatistics',
                request_serializer=voltha__protos_dot_openolt__pb2.OnuPacket.SerializeToString,
                response_deserializer=voltha__protos_dot_openolt__pb2.GemPortStatistics.FromString,
                )
        self.CreateTrafficSchedulers = channel.unary_unary(
                '/openolt.Openolt/CreateTrafficSchedulers',
                request_serializer=voltha__protos_dot_tech__profile__pb2.TrafficSchedulers.SerializeToString,
                response_deserializer=voltha__protos_dot_openolt__pb2.Empty.FromString,
                )
        self.RemoveTrafficSchedulers = channel.unary_unary(
                '/openolt.Openolt/RemoveTrafficSchedulers',
                request_serializer=voltha__protos_dot_tech__profile__pb2.TrafficSchedulers.SerializeToString,
                response_deserializer=voltha__protos_dot_openolt__pb2.Empty.FromString,
                )
        self.CreateTrafficQueues = channel.unary_unary(
                '/openolt.Openolt/CreateTrafficQueues',
                request_serializer=voltha__protos_dot_tech__profile__pb2.TrafficQueues.SerializeToString,
                response_deserializer=voltha__protos_dot_openolt__pb2.Empty.FromString,
                )
        self.RemoveTrafficQueues = channel.unary_unary(
                '/openolt.Openolt/RemoveTrafficQueues',
                request_serializer=voltha__protos_dot_tech__profile__pb2.TrafficQueues.SerializeToString,
                response_deserializer=voltha__protos_dot_openolt__pb2.Empty.FromString,
                )
        self.EnableIndication = channel.unary_stream(
                '/openolt.Openolt/EnableIndication',
                request_serializer=voltha__protos_dot_openolt__pb2.Empty.SerializeToString,
                response_deserializer=voltha__protos_dot_openolt__pb2.Indication.FromString,
                )
        self.PerformGroupOperation = channel.unary_unary(
                '/openolt.Openolt/PerformGroupOperation',
                request_serializer=voltha__protos_dot_openolt__pb2.Group.SerializeToString,
                response_deserializer=voltha__protos_dot_openolt__pb2.Empty.FromString,
                )
        self.DeleteGroup = channel.unary_unary(
                '/openolt.Openolt/DeleteGroup',
                request_serializer=voltha__protos_dot_openolt__pb2.Group.SerializeToString,
                response_deserializer=voltha__protos_dot_openolt__pb2.Empty.FromString,
                )
        self.GetExtValue = channel.unary_unary(
                '/openolt.Openolt/GetExtValue',
                request_serializer=voltha__protos_dot_openolt__pb2.ValueParam.SerializeToString,
                response_deserializer=voltha__protos_dot_extensions__pb2.ReturnValues.FromString,
                )
        self.OnuItuPonAlarmSet = channel.unary_unary(
                '/openolt.Openolt/OnuItuPonAlarmSet',
                request_serializer=voltha__protos_dot_ext__config__pb2.OnuItuPonAlarm.SerializeToString,
                response_deserializer=voltha__protos_dot_openolt__pb2.Empty.FromString,
                )
        self.GetLogicalOnuDistanceZero = channel.unary_unary(
                '/openolt.Openolt/GetLogicalOnuDistanceZero',
                request_serializer=voltha__protos_dot_openolt__pb2.Onu.SerializeToString,
                response_deserializer=voltha__protos_dot_openolt__pb2.OnuLogicalDistance.FromString,
                )
        self.GetLogicalOnuDistance = channel.unary_unary(
                '/openolt.Openolt/GetLogicalOnuDistance',
                request_serializer=voltha__protos_dot_openolt__pb2.Onu.SerializeToString,
                response_deserializer=voltha__protos_dot_openolt__pb2.OnuLogicalDistance.FromString,
                )
        self.GetPonRxPower = channel.unary_unary(
                '/openolt.Openolt/GetPonRxPower',
                request_serializer=voltha__protos_dot_openolt__pb2.Onu.SerializeToString,
                response_deserializer=voltha__protos_dot_openolt__pb2.PonRxPowerData.FromString,
                )
        self.GetOnuInfo = channel.unary_unary(
                '/openolt.Openolt/GetOnuInfo',
                request_serializer=voltha__protos_dot_openolt__pb2.Onu.SerializeToString,
                response_deserializer=voltha__protos_dot_openolt__pb2.OnuInfo.FromString,
                )
        self.GetPonInterfaceInfo = channel.unary_unary(
                '/openolt.Openolt/GetPonInterfaceInfo',
                request_serializer=voltha__protos_dot_openolt__pb2.Interface.SerializeToString,
                response_deserializer=voltha__protos_dot_openolt__pb2.PonIntfInfo.FromString,
                )
        self.GetAllocIdStatistics = channel.unary_unary(
                '/openolt.Openolt/GetAllocIdStatistics',
                request_serializer=voltha__protos_dot_openolt__pb2.OnuPacket.SerializeToString,
                response_deserializer=voltha__protos_dot_openolt__pb2.OnuAllocIdStatistics.FromString,
                )
        self.GetPonPortStatistics = channel.unary_unary(
                '/openolt.Openolt/GetPonPortStatistics',
                request_serializer=voltha__protos_dot_openolt__pb2.Interface.SerializeToString,
                response_deserializer=voltha__protos_dot_common__pb2.PortStatistics.FromString,
                )
        self.GetNniPortStatistics = channel.unary_unary(
                '/openolt.Openolt/GetNniPortStatistics',
                request_serializer=voltha__protos_dot_openolt__pb2.Interface.SerializeToString,
                response_deserializer=voltha__protos_dot_common__pb2.PortStatistics.FromString,
                )
        self.DisableOnu = channel.unary_unary(
                '/openolt.Openolt/DisableOnu',
                request_serializer=voltha__protos_dot_openolt__pb2.InterfaceOnuSerialNumberOnuId.SerializeToString,
                response_deserializer=voltha__protos_dot_openolt__pb2.Empty.FromString,
                )
        self.EnableOnu = channel.unary_unary(
                '/openolt.Openolt/EnableOnu',
                request_serializer=voltha__protos_dot_openolt__pb2.InterfaceOnuSerialNumberOnuId.SerializeToString,
                response_deserializer=voltha__protos_dot_openolt__pb2.Empty.FromString,
                )
        self.DisableOnuSerialNumber = channel.unary_unary(
                '/openolt.Openolt/DisableOnuSerialNumber',
                request_serializer=voltha__protos_dot_openolt__pb2.InterfaceOnuSerialNumber.SerializeToString,
                response_deserializer=voltha__protos_dot_openolt__pb2.Empty.FromString,
                )
        self.EnableOnuSerialNumber = channel.unary_unary(
                '/openolt.Openolt/EnableOnuSerialNumber',
                request_serializer=voltha__protos_dot_openolt__pb2.InterfaceOnuSerialNumber.SerializeToString,
                response_deserializer=voltha__protos_dot_openolt__pb2.Empty.FromString,
                )


class OpenoltServicer(object):
    """Missing associated documentation comment in .proto file."""

    def DisableOlt(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReenableOlt(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ActivateOnu(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeactivateOnu(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteOnu(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def OmciMsgOut(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def OnuPacketOut(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UplinkPacketOut(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FlowAdd(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FlowRemove(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def HeartbeatCheck(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EnablePonIf(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DisablePonIf(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDeviceInfo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Reboot(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CollectStatistics(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetOnuStatistics(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetGemPortStatistics(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateTrafficSchedulers(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemoveTrafficSchedulers(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateTrafficQueues(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemoveTrafficQueues(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EnableIndication(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PerformGroupOperation(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteGroup(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetExtValue(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def OnuItuPonAlarmSet(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetLogicalOnuDistanceZero(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetLogicalOnuDistance(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPonRxPower(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetOnuInfo(self, request, context):
        """
        GetOnuInfo takes Onu id, serialnumber, and pon interface as argument from the onu structure.
        Returns the Onu info from the device.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPonInterfaceInfo(self, request, context):
        """
        GetPonInterfaceInfo takes the pon intf id as argument.
        Returns the pon interface information from the device.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAllocIdStatistics(self, request, context):
        """
        GetAllocIdStatistics takes onuId and allocId as argument.
        This method includes a default wait period of 10 secs before collecting the stats.
        The caller has to be aware of this wait and handle it accordingly.
        Returns AllocId statistics in the form of OnuAllocStatistics structure
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPonPortStatistics(self, request, context):
        """
        GetPonPortStatistics takes interface id and type as argument from Interface structure.
        Returns Pon port statistics in the form of PonStatsData structure.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetNniPortStatistics(self, request, context):
        """
        GetNniPortStatistics takes takes interface id and type as argument from Interface structure.
        Returns Nni port statistics in the form of NniStatsData structure
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DisableOnu(self, request, context):
        """
        Disable ONU serailnumber, disable device at PLOAM.
        Takes input as intfid, onuid, sn of the ONU.
        Returns success if the call towards the device is success, error otherwise.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EnableOnu(self, request, context):
        """
        Enables ONU serailnumber, enable device at PLOAM.
        Takes input as intfid, onuid, sn of the ONU.
        Returns success if the call towards the device is success, error otherwise.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DisableOnuSerialNumber(self, request, context):
        """
        Disable ONU serailnumber, disable device at PLOAM
        Takes input as intfid and sn of the ONU. Generally used when the onu is not present in the OLT.
        Returns success if the call towards the device is success, error otherwise.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EnableOnuSerialNumber(self, request, context):
        """
        Enables ONU serailnumber, enable device at PLOAM
        Takes input as intfid and sn of the ONU. Generally used when the onu is not present in the OLT.
        Returns success if the call towards the device is success, error otherwise.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_OpenoltServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'DisableOlt': grpc.unary_unary_rpc_method_handler(
                    servicer.DisableOlt,
                    request_deserializer=voltha__protos_dot_openolt__pb2.Empty.FromString,
                    response_serializer=voltha__protos_dot_openolt__pb2.Empty.SerializeToString,
            ),
            'ReenableOlt': grpc.unary_unary_rpc_method_handler(
                    servicer.ReenableOlt,
                    request_deserializer=voltha__protos_dot_openolt__pb2.Empty.FromString,
                    response_serializer=voltha__protos_dot_openolt__pb2.Empty.SerializeToString,
            ),
            'ActivateOnu': grpc.unary_unary_rpc_method_handler(
                    servicer.ActivateOnu,
                    request_deserializer=voltha__protos_dot_openolt__pb2.Onu.FromString,
                    response_serializer=voltha__protos_dot_openolt__pb2.Empty.SerializeToString,
            ),
            'DeactivateOnu': grpc.unary_unary_rpc_method_handler(
                    servicer.DeactivateOnu,
                    request_deserializer=voltha__protos_dot_openolt__pb2.Onu.FromString,
                    response_serializer=voltha__protos_dot_openolt__pb2.Empty.SerializeToString,
            ),
            'DeleteOnu': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteOnu,
                    request_deserializer=voltha__protos_dot_openolt__pb2.Onu.FromString,
                    response_serializer=voltha__protos_dot_openolt__pb2.Empty.SerializeToString,
            ),
            'OmciMsgOut': grpc.unary_unary_rpc_method_handler(
                    servicer.OmciMsgOut,
                    request_deserializer=voltha__protos_dot_openolt__pb2.OmciMsg.FromString,
                    response_serializer=voltha__protos_dot_openolt__pb2.Empty.SerializeToString,
            ),
            'OnuPacketOut': grpc.unary_unary_rpc_method_handler(
                    servicer.OnuPacketOut,
                    request_deserializer=voltha__protos_dot_openolt__pb2.OnuPacket.FromString,
                    response_serializer=voltha__protos_dot_openolt__pb2.Empty.SerializeToString,
            ),
            'UplinkPacketOut': grpc.unary_unary_rpc_method_handler(
                    servicer.UplinkPacketOut,
                    request_deserializer=voltha__protos_dot_openolt__pb2.UplinkPacket.FromString,
                    response_serializer=voltha__protos_dot_openolt__pb2.Empty.SerializeToString,
            ),
            'FlowAdd': grpc.unary_unary_rpc_method_handler(
                    servicer.FlowAdd,
                    request_deserializer=voltha__protos_dot_openolt__pb2.Flow.FromString,
                    response_serializer=voltha__protos_dot_openolt__pb2.Empty.SerializeToString,
            ),
            'FlowRemove': grpc.unary_unary_rpc_method_handler(
                    servicer.FlowRemove,
                    request_deserializer=voltha__protos_dot_openolt__pb2.Flow.FromString,
                    response_serializer=voltha__protos_dot_openolt__pb2.Empty.SerializeToString,
            ),
            'HeartbeatCheck': grpc.unary_unary_rpc_method_handler(
                    servicer.HeartbeatCheck,
                    request_deserializer=voltha__protos_dot_openolt__pb2.Empty.FromString,
                    response_serializer=voltha__protos_dot_openolt__pb2.Heartbeat.SerializeToString,
            ),
            'EnablePonIf': grpc.unary_unary_rpc_method_handler(
                    servicer.EnablePonIf,
                    request_deserializer=voltha__protos_dot_openolt__pb2.Interface.FromString,
                    response_serializer=voltha__protos_dot_openolt__pb2.Empty.SerializeToString,
            ),
            'DisablePonIf': grpc.unary_unary_rpc_method_handler(
                    servicer.DisablePonIf,
                    request_deserializer=voltha__protos_dot_openolt__pb2.Interface.FromString,
                    response_serializer=voltha__protos_dot_openolt__pb2.Empty.SerializeToString,
            ),
            'GetDeviceInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDeviceInfo,
                    request_deserializer=voltha__protos_dot_openolt__pb2.Empty.FromString,
                    response_serializer=voltha__protos_dot_openolt__pb2.DeviceInfo.SerializeToString,
            ),
            'Reboot': grpc.unary_unary_rpc_method_handler(
                    servicer.Reboot,
                    request_deserializer=voltha__protos_dot_openolt__pb2.Empty.FromString,
                    response_serializer=voltha__protos_dot_openolt__pb2.Empty.SerializeToString,
            ),
            'CollectStatistics': grpc.unary_unary_rpc_method_handler(
                    servicer.CollectStatistics,
                    request_deserializer=voltha__protos_dot_openolt__pb2.Empty.FromString,
                    response_serializer=voltha__protos_dot_openolt__pb2.Empty.SerializeToString,
            ),
            'GetOnuStatistics': grpc.unary_unary_rpc_method_handler(
                    servicer.GetOnuStatistics,
                    request_deserializer=voltha__protos_dot_openolt__pb2.Onu.FromString,
                    response_serializer=voltha__protos_dot_openolt__pb2.OnuStatistics.SerializeToString,
            ),
            'GetGemPortStatistics': grpc.unary_unary_rpc_method_handler(
                    servicer.GetGemPortStatistics,
                    request_deserializer=voltha__protos_dot_openolt__pb2.OnuPacket.FromString,
                    response_serializer=voltha__protos_dot_openolt__pb2.GemPortStatistics.SerializeToString,
            ),
            'CreateTrafficSchedulers': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateTrafficSchedulers,
                    request_deserializer=voltha__protos_dot_tech__profile__pb2.TrafficSchedulers.FromString,
                    response_serializer=voltha__protos_dot_openolt__pb2.Empty.SerializeToString,
            ),
            'RemoveTrafficSchedulers': grpc.unary_unary_rpc_method_handler(
                    servicer.RemoveTrafficSchedulers,
                    request_deserializer=voltha__protos_dot_tech__profile__pb2.TrafficSchedulers.FromString,
                    response_serializer=voltha__protos_dot_openolt__pb2.Empty.SerializeToString,
            ),
            'CreateTrafficQueues': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateTrafficQueues,
                    request_deserializer=voltha__protos_dot_tech__profile__pb2.TrafficQueues.FromString,
                    response_serializer=voltha__protos_dot_openolt__pb2.Empty.SerializeToString,
            ),
            'RemoveTrafficQueues': grpc.unary_unary_rpc_method_handler(
                    servicer.RemoveTrafficQueues,
                    request_deserializer=voltha__protos_dot_tech__profile__pb2.TrafficQueues.FromString,
                    response_serializer=voltha__protos_dot_openolt__pb2.Empty.SerializeToString,
            ),
            'EnableIndication': grpc.unary_stream_rpc_method_handler(
                    servicer.EnableIndication,
                    request_deserializer=voltha__protos_dot_openolt__pb2.Empty.FromString,
                    response_serializer=voltha__protos_dot_openolt__pb2.Indication.SerializeToString,
            ),
            'PerformGroupOperation': grpc.unary_unary_rpc_method_handler(
                    servicer.PerformGroupOperation,
                    request_deserializer=voltha__protos_dot_openolt__pb2.Group.FromString,
                    response_serializer=voltha__protos_dot_openolt__pb2.Empty.SerializeToString,
            ),
            'DeleteGroup': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteGroup,
                    request_deserializer=voltha__protos_dot_openolt__pb2.Group.FromString,
                    response_serializer=voltha__protos_dot_openolt__pb2.Empty.SerializeToString,
            ),
            'GetExtValue': grpc.unary_unary_rpc_method_handler(
                    servicer.GetExtValue,
                    request_deserializer=voltha__protos_dot_openolt__pb2.ValueParam.FromString,
                    response_serializer=voltha__protos_dot_extensions__pb2.ReturnValues.SerializeToString,
            ),
            'OnuItuPonAlarmSet': grpc.unary_unary_rpc_method_handler(
                    servicer.OnuItuPonAlarmSet,
                    request_deserializer=voltha__protos_dot_ext__config__pb2.OnuItuPonAlarm.FromString,
                    response_serializer=voltha__protos_dot_openolt__pb2.Empty.SerializeToString,
            ),
            'GetLogicalOnuDistanceZero': grpc.unary_unary_rpc_method_handler(
                    servicer.GetLogicalOnuDistanceZero,
                    request_deserializer=voltha__protos_dot_openolt__pb2.Onu.FromString,
                    response_serializer=voltha__protos_dot_openolt__pb2.OnuLogicalDistance.SerializeToString,
            ),
            'GetLogicalOnuDistance': grpc.unary_unary_rpc_method_handler(
                    servicer.GetLogicalOnuDistance,
                    request_deserializer=voltha__protos_dot_openolt__pb2.Onu.FromString,
                    response_serializer=voltha__protos_dot_openolt__pb2.OnuLogicalDistance.SerializeToString,
            ),
            'GetPonRxPower': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPonRxPower,
                    request_deserializer=voltha__protos_dot_openolt__pb2.Onu.FromString,
                    response_serializer=voltha__protos_dot_openolt__pb2.PonRxPowerData.SerializeToString,
            ),
            'GetOnuInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.GetOnuInfo,
                    request_deserializer=voltha__protos_dot_openolt__pb2.Onu.FromString,
                    response_serializer=voltha__protos_dot_openolt__pb2.OnuInfo.SerializeToString,
            ),
            'GetPonInterfaceInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPonInterfaceInfo,
                    request_deserializer=voltha__protos_dot_openolt__pb2.Interface.FromString,
                    response_serializer=voltha__protos_dot_openolt__pb2.PonIntfInfo.SerializeToString,
            ),
            'GetAllocIdStatistics': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAllocIdStatistics,
                    request_deserializer=voltha__protos_dot_openolt__pb2.OnuPacket.FromString,
                    response_serializer=voltha__protos_dot_openolt__pb2.OnuAllocIdStatistics.SerializeToString,
            ),
            'GetPonPortStatistics': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPonPortStatistics,
                    request_deserializer=voltha__protos_dot_openolt__pb2.Interface.FromString,
                    response_serializer=voltha__protos_dot_common__pb2.PortStatistics.SerializeToString,
            ),
            'GetNniPortStatistics': grpc.unary_unary_rpc_method_handler(
                    servicer.GetNniPortStatistics,
                    request_deserializer=voltha__protos_dot_openolt__pb2.Interface.FromString,
                    response_serializer=voltha__protos_dot_common__pb2.PortStatistics.SerializeToString,
            ),
            'DisableOnu': grpc.unary_unary_rpc_method_handler(
                    servicer.DisableOnu,
                    request_deserializer=voltha__protos_dot_openolt__pb2.InterfaceOnuSerialNumberOnuId.FromString,
                    response_serializer=voltha__protos_dot_openolt__pb2.Empty.SerializeToString,
            ),
            'EnableOnu': grpc.unary_unary_rpc_method_handler(
                    servicer.EnableOnu,
                    request_deserializer=voltha__protos_dot_openolt__pb2.InterfaceOnuSerialNumberOnuId.FromString,
                    response_serializer=voltha__protos_dot_openolt__pb2.Empty.SerializeToString,
            ),
            'DisableOnuSerialNumber': grpc.unary_unary_rpc_method_handler(
                    servicer.DisableOnuSerialNumber,
                    request_deserializer=voltha__protos_dot_openolt__pb2.InterfaceOnuSerialNumber.FromString,
                    response_serializer=voltha__protos_dot_openolt__pb2.Empty.SerializeToString,
            ),
            'EnableOnuSerialNumber': grpc.unary_unary_rpc_method_handler(
                    servicer.EnableOnuSerialNumber,
                    request_deserializer=voltha__protos_dot_openolt__pb2.InterfaceOnuSerialNumber.FromString,
                    response_serializer=voltha__protos_dot_openolt__pb2.Empty.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'openolt.Openolt', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Openolt(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def DisableOlt(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openolt.Openolt/DisableOlt',
            voltha__protos_dot_openolt__pb2.Empty.SerializeToString,
            voltha__protos_dot_openolt__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReenableOlt(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openolt.Openolt/ReenableOlt',
            voltha__protos_dot_openolt__pb2.Empty.SerializeToString,
            voltha__protos_dot_openolt__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ActivateOnu(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openolt.Openolt/ActivateOnu',
            voltha__protos_dot_openolt__pb2.Onu.SerializeToString,
            voltha__protos_dot_openolt__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeactivateOnu(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openolt.Openolt/DeactivateOnu',
            voltha__protos_dot_openolt__pb2.Onu.SerializeToString,
            voltha__protos_dot_openolt__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteOnu(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openolt.Openolt/DeleteOnu',
            voltha__protos_dot_openolt__pb2.Onu.SerializeToString,
            voltha__protos_dot_openolt__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def OmciMsgOut(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openolt.Openolt/OmciMsgOut',
            voltha__protos_dot_openolt__pb2.OmciMsg.SerializeToString,
            voltha__protos_dot_openolt__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def OnuPacketOut(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openolt.Openolt/OnuPacketOut',
            voltha__protos_dot_openolt__pb2.OnuPacket.SerializeToString,
            voltha__protos_dot_openolt__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UplinkPacketOut(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openolt.Openolt/UplinkPacketOut',
            voltha__protos_dot_openolt__pb2.UplinkPacket.SerializeToString,
            voltha__protos_dot_openolt__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FlowAdd(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openolt.Openolt/FlowAdd',
            voltha__protos_dot_openolt__pb2.Flow.SerializeToString,
            voltha__protos_dot_openolt__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FlowRemove(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openolt.Openolt/FlowRemove',
            voltha__protos_dot_openolt__pb2.Flow.SerializeToString,
            voltha__protos_dot_openolt__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def HeartbeatCheck(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openolt.Openolt/HeartbeatCheck',
            voltha__protos_dot_openolt__pb2.Empty.SerializeToString,
            voltha__protos_dot_openolt__pb2.Heartbeat.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EnablePonIf(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openolt.Openolt/EnablePonIf',
            voltha__protos_dot_openolt__pb2.Interface.SerializeToString,
            voltha__protos_dot_openolt__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DisablePonIf(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openolt.Openolt/DisablePonIf',
            voltha__protos_dot_openolt__pb2.Interface.SerializeToString,
            voltha__protos_dot_openolt__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDeviceInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openolt.Openolt/GetDeviceInfo',
            voltha__protos_dot_openolt__pb2.Empty.SerializeToString,
            voltha__protos_dot_openolt__pb2.DeviceInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Reboot(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openolt.Openolt/Reboot',
            voltha__protos_dot_openolt__pb2.Empty.SerializeToString,
            voltha__protos_dot_openolt__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CollectStatistics(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openolt.Openolt/CollectStatistics',
            voltha__protos_dot_openolt__pb2.Empty.SerializeToString,
            voltha__protos_dot_openolt__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetOnuStatistics(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openolt.Openolt/GetOnuStatistics',
            voltha__protos_dot_openolt__pb2.Onu.SerializeToString,
            voltha__protos_dot_openolt__pb2.OnuStatistics.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetGemPortStatistics(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openolt.Openolt/GetGemPortStatistics',
            voltha__protos_dot_openolt__pb2.OnuPacket.SerializeToString,
            voltha__protos_dot_openolt__pb2.GemPortStatistics.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateTrafficSchedulers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openolt.Openolt/CreateTrafficSchedulers',
            voltha__protos_dot_tech__profile__pb2.TrafficSchedulers.SerializeToString,
            voltha__protos_dot_openolt__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RemoveTrafficSchedulers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openolt.Openolt/RemoveTrafficSchedulers',
            voltha__protos_dot_tech__profile__pb2.TrafficSchedulers.SerializeToString,
            voltha__protos_dot_openolt__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateTrafficQueues(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openolt.Openolt/CreateTrafficQueues',
            voltha__protos_dot_tech__profile__pb2.TrafficQueues.SerializeToString,
            voltha__protos_dot_openolt__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RemoveTrafficQueues(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openolt.Openolt/RemoveTrafficQueues',
            voltha__protos_dot_tech__profile__pb2.TrafficQueues.SerializeToString,
            voltha__protos_dot_openolt__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EnableIndication(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/openolt.Openolt/EnableIndication',
            voltha__protos_dot_openolt__pb2.Empty.SerializeToString,
            voltha__protos_dot_openolt__pb2.Indication.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PerformGroupOperation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openolt.Openolt/PerformGroupOperation',
            voltha__protos_dot_openolt__pb2.Group.SerializeToString,
            voltha__protos_dot_openolt__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteGroup(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openolt.Openolt/DeleteGroup',
            voltha__protos_dot_openolt__pb2.Group.SerializeToString,
            voltha__protos_dot_openolt__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetExtValue(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openolt.Openolt/GetExtValue',
            voltha__protos_dot_openolt__pb2.ValueParam.SerializeToString,
            voltha__protos_dot_extensions__pb2.ReturnValues.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def OnuItuPonAlarmSet(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openolt.Openolt/OnuItuPonAlarmSet',
            voltha__protos_dot_ext__config__pb2.OnuItuPonAlarm.SerializeToString,
            voltha__protos_dot_openolt__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetLogicalOnuDistanceZero(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openolt.Openolt/GetLogicalOnuDistanceZero',
            voltha__protos_dot_openolt__pb2.Onu.SerializeToString,
            voltha__protos_dot_openolt__pb2.OnuLogicalDistance.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetLogicalOnuDistance(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openolt.Openolt/GetLogicalOnuDistance',
            voltha__protos_dot_openolt__pb2.Onu.SerializeToString,
            voltha__protos_dot_openolt__pb2.OnuLogicalDistance.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetPonRxPower(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openolt.Openolt/GetPonRxPower',
            voltha__protos_dot_openolt__pb2.Onu.SerializeToString,
            voltha__protos_dot_openolt__pb2.PonRxPowerData.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetOnuInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openolt.Openolt/GetOnuInfo',
            voltha__protos_dot_openolt__pb2.Onu.SerializeToString,
            voltha__protos_dot_openolt__pb2.OnuInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetPonInterfaceInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openolt.Openolt/GetPonInterfaceInfo',
            voltha__protos_dot_openolt__pb2.Interface.SerializeToString,
            voltha__protos_dot_openolt__pb2.PonIntfInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAllocIdStatistics(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openolt.Openolt/GetAllocIdStatistics',
            voltha__protos_dot_openolt__pb2.OnuPacket.SerializeToString,
            voltha__protos_dot_openolt__pb2.OnuAllocIdStatistics.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetPonPortStatistics(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openolt.Openolt/GetPonPortStatistics',
            voltha__protos_dot_openolt__pb2.Interface.SerializeToString,
            voltha__protos_dot_common__pb2.PortStatistics.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetNniPortStatistics(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openolt.Openolt/GetNniPortStatistics',
            voltha__protos_dot_openolt__pb2.Interface.SerializeToString,
            voltha__protos_dot_common__pb2.PortStatistics.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DisableOnu(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openolt.Openolt/DisableOnu',
            voltha__protos_dot_openolt__pb2.InterfaceOnuSerialNumberOnuId.SerializeToString,
            voltha__protos_dot_openolt__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EnableOnu(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openolt.Openolt/EnableOnu',
            voltha__protos_dot_openolt__pb2.InterfaceOnuSerialNumberOnuId.SerializeToString,
            voltha__protos_dot_openolt__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DisableOnuSerialNumber(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openolt.Openolt/DisableOnuSerialNumber',
            voltha__protos_dot_openolt__pb2.InterfaceOnuSerialNumber.SerializeToString,
            voltha__protos_dot_openolt__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EnableOnuSerialNumber(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openolt.Openolt/EnableOnuSerialNumber',
            voltha__protos_dot_openolt__pb2.InterfaceOnuSerialNumber.SerializeToString,
            voltha__protos_dot_openolt__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: voltha_protos/ext_config.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1evoltha_protos/ext_config.proto\x12\x06\x63onfig\"S\n\x0b\x41larmConfig\x12:\n\x18onu_itu_pon_alarm_config\x18\x01 \x01(\x0b\x32\x16.config.OnuItuPonAlarmH\x00\x42\x08\n\x06\x63onfig\"\xb9\x07\n\x0eOnuItuPonAlarm\x12\x0e\n\x06pon_ni\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x30\n\x08\x61larm_id\x18\x03 \x01(\x0e\x32\x1e.config.OnuItuPonAlarm.AlarmID\x12Q\n\x19\x61larm_reporting_condition\x18\x04 \x01(\x0e\x32..config.OnuItuPonAlarm.AlarmReportingCondition\x12K\n\x15rate_threshold_config\x18\x05 \x01(\x0b\x32*.config.OnuItuPonAlarm.RateThresholdConfigH\x00\x12\x43\n\x11rate_range_config\x18\x06 \x01(\x0b\x32&.config.OnuItuPonAlarm.RateRangeConfigH\x00\x12M\n\x16value_threshold_config\x18\x07 \x01(\x0b\x32+.config.OnuItuPonAlarm.ValueThresholdConfigH\x00\x1a=\n\x08SoakTime\x12\x18\n\x10\x61\x63tive_soak_time\x18\x01 \x01(\x07\x12\x17\n\x0f\x63lear_soak_time\x18\x02 \x01(\x07\x1a\x88\x01\n\x13RateThresholdConfig\x12\x1d\n\x15rate_threshold_rising\x18\x01 \x01(\x06\x12\x1e\n\x16rate_threshold_falling\x18\x02 \x01(\x06\x12\x32\n\tsoak_time\x18\x03 \x01(\x0b\x32\x1f.config.OnuItuPonAlarm.SoakTime\x1ay\n\x0fRateRangeConfig\x12\x18\n\x10rate_range_lower\x18\x01 \x01(\x06\x12\x18\n\x10rate_range_upper\x18\x02 \x01(\x06\x12\x32\n\tsoak_time\x18\x03 \x01(\x0b\x32\x1f.config.OnuItuPonAlarm.SoakTime\x1a\x63\n\x14ValueThresholdConfig\x12\x17\n\x0fthreshold_limit\x18\x01 \x01(\x06\x12\x32\n\tsoak_time\x18\x02 \x01(\x0b\x32\x1f.config.OnuItuPonAlarm.SoakTime\"\x19\n\x07\x41larmID\x12\x0e\n\nRDI_ERRORS\x10\x00\"R\n\x17\x41larmReportingCondition\x12\x12\n\x0eRATE_THRESHOLD\x10\x00\x12\x0e\n\nRATE_RANGE\x10\x01\x12\x13\n\x0fVALUE_THRESHOLD\x10\x02\x42\x08\n\x06\x63onfigBI\n\x13org.opencord.volthaZ2github.com/opencord/voltha-protos/v5/go/ext/configb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'voltha_protos.ext_config_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\023org.opencord.volthaZ2github.com/opencord/voltha-protos/v5/go/ext/config'
  _globals['_ALARMCONFIG']._serialized_start=42
  _globals['_ALARMCONFIG']._serialized_end=125
  _globals['_ONUITUPONALARM']._serialized_start=128
  _globals['_ONUITUPONALARM']._serialized_end=1081
  _globals['_ONUITUPONALARM_SOAKTIME']._serialized_start=536
  _globals['_ONUITUPONALARM_SOAKTIME']._serialized_end=597
  _globals['_ONUITUPONALARM_RATETHRESHOLDCONFIG']._serialized_start=600
  _globals['_ONUITUPONALARM_RATETHRESHOLDCONFIG']._serialized_end=736
  _globals['_ONUITUPONALARM_RATERANGECONFIG']._serialized_start=738
  _globals['_ONUITUPONALARM_RATERANGECONFIG']._serialized_end=859
  _globals['_ONUITUPONALARM_VALUETHRESHOLDCONFIG']._serialized_start=861
  _globals['_ONUITUPONALARM_VALUETHRESHOLDCONFIG']._serialized_end=960
  _globals['_ONUITUPONALARM_ALARMID']._serialized_start=962
  _globals['_ONUITUPONALARM_ALARMID']._serialized_end=987
  _globals['_ONUITUPONALARM_ALARMREPORTINGCONDITION']._serialized_start=989
  _globals['_ONUITUPONALARM_ALARMREPORTINGCONDITION']._serialized_end=1071
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: voltha_protos/common.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1avoltha_protos/common.proto\x12\x06\x63ommon\"\x12\n\x03Key\x12\x0b\n\x03key\x18\x01 \x01(\t\"\x10\n\x02ID\x12\n\n\x02id\x18\x01 \x01(\t\" \n\x03IDs\x12\x19\n\x05items\x18\x01 \x03(\x0b\x32\n.common.ID\"P\n\nConnection\x12\x10\n\x08\x65ndpoint\x18\x01 \x01(\t\x12\x13\n\x0b\x63ontextInfo\x18\x02 \x01(\t\x12\x1b\n\x13keep_alive_interval\x18\x03 \x01(\x03\"h\n\nAdminState\"Z\n\x05Types\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x12\n\x0ePREPROVISIONED\x10\x01\x12\x0b\n\x07\x45NABLED\x10\x02\x12\x0c\n\x08\x44ISABLED\x10\x03\x12\x15\n\x11\x44OWNLOADING_IMAGE\x10\x04\"\x9f\x01\n\nOperStatus\"\x90\x01\n\x05Types\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0e\n\nDISCOVERED\x10\x01\x12\x0e\n\nACTIVATING\x10\x02\x12\x0b\n\x07TESTING\x10\x03\x12\n\n\x06\x41\x43TIVE\x10\x04\x12\n\n\x06\x46\x41ILED\x10\x05\x12\x0f\n\x0bRECONCILING\x10\x06\x12\x16\n\x12RECONCILING_FAILED\x10\x07\x12\x0c\n\x08REBOOTED\x10\x08\"E\n\rConnectStatus\"4\n\x05Types\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0f\n\x0bUNREACHABLE\x10\x01\x12\r\n\tREACHABLE\x10\x02\"\xdc\x01\n\rOperationResp\x12\x37\n\x04\x63ode\x18\x01 \x01(\x0e\x32).common.OperationResp.OperationReturnCode\x12\x17\n\x0f\x61\x64\x64itional_info\x18\x02 \x01(\t\"y\n\x13OperationReturnCode\x12\x15\n\x11OPERATION_SUCCESS\x10\x00\x12\x15\n\x11OPERATION_FAILURE\x10\x01\x12\x19\n\x15OPERATION_UNSUPPORTED\x10\x02\x12\x19\n\x15OPERATION_IN_PROGRESS\x10\x03\"\x9e\x0e\n\x0ePortStatistics\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x10\n\x08rx_bytes\x18\x02 \x01(\x06\x12\x16\n\nrx_packets\x18\x03 \x01(\x06\x42\x02\x18\x01\x12\x1c\n\x10rx_ucast_packets\x18\x04 \x01(\x06\x42\x02\x18\x01\x12\x1c\n\x10rx_mcast_packets\x18\x05 \x01(\x06\x42\x02\x18\x01\x12\x1c\n\x10rx_bcast_packets\x18\x06 \x01(\x06\x42\x02\x18\x01\x12\x1c\n\x10rx_error_packets\x18\x07 \x01(\x06\x42\x02\x18\x01\x12\x11\n\trx_frames\x18\x11 \x01(\x06\x12\x14\n\x0crx_frames_64\x18\x12 \x01(\x06\x12\x18\n\x10rx_frames_65_127\x18\x13 \x01(\x06\x12\x19\n\x11rx_frames_128_255\x18\x14 \x01(\x06\x12\x19\n\x11rx_frames_256_511\x18\x15 \x01(\x06\x12\x1a\n\x12rx_frames_512_1023\x18\x16 \x01(\x06\x12\x1b\n\x13rx_frames_1024_1518\x18\x17 \x01(\x06\x12\x1b\n\x13rx_frames_1519_2047\x18\x18 \x01(\x06\x12\x1b\n\x13rx_frames_2048_4095\x18\x19 \x01(\x06\x12\x1b\n\x13rx_frames_4096_9216\x18\x1a \x01(\x06\x12\x1c\n\x14rx_frames_9217_16383\x18\x1b \x01(\x06\x12\x15\n\rrx_crc_errors\x18\x0e \x01(\x06\x12\x1a\n\x12rxUndersizePackets\x18\' \x01(\x06\x12\x19\n\x11rxOversizePackets\x18( \x01(\x06\x12\r\n\x05rxGem\x18+ \x01(\x06\x12\x14\n\x0crxGemDropped\x18, \x01(\x06\x12\x11\n\trxGemIdle\x18- \x01(\x06\x12\x16\n\x0erxGemCorrected\x18. \x01(\x06\x12\x14\n\x0crxGemIllegal\x18/ \x01(\x06\x12\x17\n\x0frxFragmentError\x18\x30 \x01(\x06\x12\x18\n\x10rxPacketsDropped\x18\x31 \x01(\x06\x12\x1f\n\x17rxCpuOmciPacketsDropped\x18\x32 \x01(\x06\x12\r\n\x05rxCpu\x18\x33 \x01(\x06\x12\x0e\n\x06rxOmci\x18\x34 \x01(\x06\x12\x1d\n\x15rxOmciPacketsCrcError\x18\x35 \x01(\x06\x12\x19\n\x11rxFcsErrorPackets\x18> \x01(\x06\x12\x10\n\x08tx_bytes\x18\x08 \x01(\x06\x12\x16\n\ntx_packets\x18\t \x01(\x06\x42\x02\x18\x01\x12\x1c\n\x10tx_ucast_packets\x18\n \x01(\x06\x42\x02\x18\x01\x12\x1c\n\x10tx_mcast_packets\x18\x0b \x01(\x06\x42\x02\x18\x01\x12\x1c\n\x10tx_bcast_packets\x18\x0c \x01(\x06\x42\x02\x18\x01\x12\x1c\n\x10tx_error_packets\x18\r \x01(\x06\x42\x02\x18\x01\x12\x11\n\ttx_frames\x18\x1c \x01(\x06\x12\x14\n\x0ctx_frames_64\x18\x1d \x01(\x06\x12\x18\n\x10tx_frames_65_127\x18\x1e \x01(\x06\x12\x19\n\x11tx_frames_128_255\x18\x1f \x01(\x06\x12\x19\n\x11tx_frames_256_511\x18  \x01(\x06\x12\x1a\n\x12tx_frames_512_1023\x18! \x01(\x06\x12\x1b\n\x13tx_frames_1024_1518\x18\" \x01(\x06\x12\x1b\n\x13tx_frames_1519_2047\x18# \x01(\x06\x12\x1b\n\x13tx_frames_2048_4095\x18$ \x01(\x06\x12\x1b\n\x13tx_frames_4096_9216\x18% \x01(\x06\x12\x1c\n\x14tx_frames_9217_16383\x18& \x01(\x06\x12\x1a\n\x12txUndersizePackets\x18) \x01(\x06\x12\x19\n\x11txOversizePackets\x18* \x01(\x06\x12\r\n\x05txGem\x18\x36 \x01(\x06\x12\r\n\x05txCpu\x18\x37 \x01(\x06\x12\x0e\n\x06txOmci\x18\x38 \x01(\x06\x12\x1e\n\x16txDroppedIllegalLength\x18\x39 \x01(\x06\x12\x19\n\x11txDroppedTpidMiss\x18: \x01(\x06\x12\x18\n\x10txDroppedVidMiss\x18; \x01(\x06\x12\x16\n\x0etxDroppedTotal\x18< \x01(\x06\x12\x12\n\nbip_errors\x18\x0f \x01(\x06\x12\x11\n\tbip_units\x18= \x01(\x06\x12\x11\n\ttimestamp\x18\x10 \x01(\x07\x12\x17\n\x0frx_ucast_frames\x18? \x01(\x06\x12\x17\n\x0frx_mcast_frames\x18@ \x01(\x06\x12\x17\n\x0frx_bcast_frames\x18\x41 \x01(\x06\x12\x17\n\x0frx_error_frames\x18\x42 \x01(\x06\x12\x17\n\x0frx_right_frames\x18\x43 \x01(\x06\x12\x17\n\x0ftx_ucast_frames\x18\x44 \x01(\x06\x12\x17\n\x0ftx_mcast_frames\x18\x45 \x01(\x06\x12\x17\n\x0ftx_bcast_frames\x18\x46 \x01(\x06\x12\x17\n\x0ftx_error_frames\x18G \x01(\x06\x12\x1b\n\x13rx_discarded_frames\x18H \x01(\x06*\x1c\n\x0cTestModeKeys\x12\x0c\n\x08\x61pi_test\x10\x00\x42\x45\n\x13org.opencord.volthaZ.github.com/opencord/voltha-protos/v5/go/commonb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'voltha_protos.common_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\023org.opencord.volthaZ.github.com/opencord/voltha-protos/v5/go/common'
  _globals['_PORTSTATISTICS'].fields_by_name['rx_packets']._options = None
  _globals['_PORTSTATISTICS'].fields_by_name['rx_packets']._serialized_options = b'\030\001'
  _globals['_PORTSTATISTICS'].fields_by_name['rx_ucast_packets']._options = None
  _globals['_PORTSTATISTICS'].fields_by_name['rx_ucast_packets']._serialized_options = b'\030\001'
  _globals['_PORTSTATISTICS'].fields_by_name['rx_mcast_packets']._options = None
  _globals['_PORTSTATISTICS'].fields_by_name['rx_mcast_packets']._serialized_options = b'\030\001'
  _globals['_PORTSTATISTICS'].fields_by_name['rx_bcast_packets']._options = None
  _globals['_PORTSTATISTICS'].fields_by_name['rx_bcast_packets']._serialized_options = b'\030\001'
  _globals['_PORTSTATISTICS'].fields_by_name['rx_error_packets']._options = None
  _globals['_PORTSTATISTICS'].fields_by_name['rx_error_packets']._serialized_options = b'\030\001'
  _globals['_PORTSTATISTICS'].fields_by_name['tx_packets']._options = None
  _globals['_PORTSTATISTICS'].fields_by_name['tx_packets']._serialized_options = b'\030\001'
  _globals['_PORTSTATISTICS'].fields_by_name['tx_ucast_packets']._options = None
  _globals['_PORTSTATISTICS'].fields_by_name['tx_ucast_packets']._serialized_options = b'\030\001'
  _globals['_PORTSTATISTICS'].fields_by_name['tx_mcast_packets']._options = None
  _globals['_PORTSTATISTICS'].fields_by_name['tx_mcast_packets']._serialized_options = b'\030\001'
  _globals['_PORTSTATISTICS'].fields_by_name['tx_bcast_packets']._options = None
  _globals['_PORTSTATISTICS'].fields_by_name['tx_bcast_packets']._serialized_options = b'\030\001'
  _globals['_PORTSTATISTICS'].fields_by_name['tx_error_packets']._options = None
  _globals['_PORTSTATISTICS'].fields_by_name['tx_error_packets']._serialized_options = b'\030\001'
  _globals['_TESTMODEKEYS']._serialized_start=2579
  _globals['_TESTMODEKEYS']._serialized_end=2607
  _globals['_KEY']._serialized_start=38
  _globals['_KEY']._serialized_end=56
  _globals['_ID']._serialized_start=58
  _globals['_ID']._serialized_end=74
  _globals['_IDS']._serialized_start=76
  _globals['_IDS']._serialized_end=108
  _globals['_CONNECTION']._serialized_start=110
  _globals['_CONNECTION']._serialized_end=190
  _globals['_ADMINSTATE']._serialized_start=192
  _globals['_ADMINSTATE']._serialized_end=296
  _globals['_ADMINSTATE_TYPES']._serialized_start=206
  _globals['_ADMINSTATE_TYPES']._serialized_end=296
  _globals['_OPERSTATUS']._serialized_start=299
  _globals['_OPERSTATUS']._serialized_end=458
  _globals['_OPERSTATUS_TYPES']._serialized_start=314
  _globals['_OPERSTATUS_TYPES']._serialized_end=458
  _globals['_CONNECTSTATUS']._serialized_start=460
  _globals['_CONNECTSTATUS']._serialized_end=529
  _globals['_CONNECTSTATUS_TYPES']._serialized_start=477
  _globals['_CONNECTSTATUS_TYPES']._serialized_end=529
  _globals['_OPERATIONRESP']._serialized_start=532
  _globals['_OPERATIONRESP']._serialized_end=752
  _globals['_OPERATIONRESP_OPERATIONRETURNCODE']._serialized_start=631
  _globals['_OPERATIONRESP_OPERATIONRETURNCODE']._serialized_end=752
  _globals['_PORTSTATISTICS']._serialized_start=755
  _globals['_PORTSTATISTICS']._serialized_end=2577
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: voltha_protos/voltha.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from voltha_protos import common_pb2 as voltha__protos_dot_common__pb2
from voltha_protos import health_pb2 as voltha__protos_dot_health__pb2
from voltha_protos import logical_device_pb2 as voltha__protos_dot_logical__device__pb2
from voltha_protos import device_pb2 as voltha__protos_dot_device__pb2
from voltha_protos import adapter_pb2 as voltha__protos_dot_adapter__pb2
from voltha_protos import openflow_13_pb2 as voltha__protos_dot_openflow__13__pb2
from voltha_protos import events_pb2 as voltha__protos_dot_events__pb2
from voltha_protos import extensions_pb2 as voltha__protos_dot_extensions__pb2
from voltha_protos import voip_system_profile_pb2 as voltha__protos_dot_voip__system__profile__pb2
from voltha_protos import voip_user_profile_pb2 as voltha__protos_dot_voip__user__profile__pb2
from voltha_protos import omci_mib_db_pb2 as voltha__protos_dot_omci__mib__db__pb2
from voltha_protos import omci_alarm_db_pb2 as voltha__protos_dot_omci__alarm__db__pb2
from voltha_protos import omci_test_pb2 as voltha__protos_dot_omci__test__pb2

from voltha_protos.common_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1avoltha_protos/voltha.proto\x12\x06voltha\x1a\x1cgoogle/api/annotations.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1avoltha_protos/common.proto\x1a\x1avoltha_protos/health.proto\x1a\"voltha_protos/logical_device.proto\x1a\x1avoltha_protos/device.proto\x1a\x1bvoltha_protos/adapter.proto\x1a\x1fvoltha_protos/openflow_13.proto\x1a\x1avoltha_protos/events.proto\x1a\x1evoltha_protos/extensions.proto\x1a\'voltha_protos/voip_system_profile.proto\x1a%voltha_protos/voip_user_profile.proto\x1a\x1fvoltha_protos/omci_mib_db.proto\x1a!voltha_protos/omci_alarm_db.proto\x1a\x1dvoltha_protos/omci_test.proto\"I\n\x0c\x43oreInstance\x12\x13\n\x0binstance_id\x18\x01 \x01(\t\x12$\n\x06health\x18\x02 \x01(\x0b\x32\x14.health.HealthStatus\"4\n\rCoreInstances\x12#\n\x05items\x18\x01 \x03(\x0b\x32\x14.voltha.CoreInstance\"\xd5\x02\n\x06Voltha\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\"\n\x08\x61\x64\x61pters\x18\x02 \x03(\x0b\x32\x10.adapter.Adapter\x12\x36\n\x0flogical_devices\x18\x03 \x03(\x0b\x32\x1d.logical_device.LogicalDevice\x12\x1f\n\x07\x64\x65vices\x18\x04 \x03(\x0b\x32\x0e.device.Device\x12(\n\x0c\x64\x65vice_types\x18\x05 \x03(\x0b\x32\x12.device.DeviceType\x12)\n\revent_filters\x18\x07 \x03(\x0b\x32\x12.event.EventFilter\x12.\n\x11omci_mib_database\x18\x1c \x03(\x0b\x32\x13.omci.MibDeviceData\x12\x32\n\x13omci_alarm_database\x18\x1d \x03(\x0b\x32\x15.omci.AlarmDeviceDataJ\x04\x08\x06\x10\x07\x32\xbb;\n\rVolthaService\x12\x44\n\tGetVoltha\x12\x16.google.protobuf.Empty\x1a\x0e.voltha.Voltha\"\x0f\x82\xd3\xe4\x93\x02\t\x12\x07/api/v1\x12]\n\x11ListCoreInstances\x12\x16.google.protobuf.Empty\x1a\x15.voltha.CoreInstances\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/api/v1/instances\x12S\n\x0fGetCoreInstance\x12\n.common.ID\x1a\x14.voltha.CoreInstance\"\x1e\x82\xd3\xe4\x93\x02\x18\x12\x16/api/v1/instances/{id}\x12S\n\x0cListAdapters\x12\x16.google.protobuf.Empty\x1a\x11.adapter.Adapters\"\x18\x82\xd3\xe4\x93\x02\x12\x12\x10/api/v1/adapters\x12m\n\x12ListLogicalDevices\x12\x16.google.protobuf.Empty\x1a\x1e.logical_device.LogicalDevices\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/api/v1/logical_devices\x12\x63\n\x10GetLogicalDevice\x12\n.common.ID\x1a\x1d.logical_device.LogicalDevice\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/api/v1/logical_devices/{id}\x12n\n\x16ListLogicalDevicePorts\x12\n.common.ID\x1a\x1c.logical_device.LogicalPorts\"*\x82\xd3\xe4\x93\x02$\x12\"/api/v1/logical_devices/{id}/ports\x12\x88\x01\n\x14GetLogicalDevicePort\x12\x1d.logical_device.LogicalPortId\x1a\x1b.logical_device.LogicalPort\"4\x82\xd3\xe4\x93\x02.\x12,/api/v1/logical_devices/{id}/ports/{port_id}\x12\x8d\x01\n\x17\x45nableLogicalDevicePort\x12\x1d.logical_device.LogicalPortId\x1a\x16.google.protobuf.Empty\";\x82\xd3\xe4\x93\x02\x35\"3/api/v1/logical_devices/{id}/ports/{port_id}/enable\x12\x8f\x01\n\x18\x44isableLogicalDevicePort\x12\x1d.logical_device.LogicalPortId\x1a\x16.google.protobuf.Empty\"<\x82\xd3\xe4\x93\x02\x36\"4/api/v1/logical_devices/{id}/ports/{port_id}/disable\x12\x64\n\x16ListLogicalDeviceFlows\x12\n.common.ID\x1a\x12.openflow_13.Flows\"*\x82\xd3\xe4\x93\x02$\x12\"/api/v1/logical_devices/{id}/flows\x12\x83\x01\n\x1cUpdateLogicalDeviceFlowTable\x12\x1c.openflow_13.FlowTableUpdate\x1a\x16.google.protobuf.Empty\"-\x82\xd3\xe4\x93\x02\'\"\"/api/v1/logical_devices/{id}/flows:\x01*\x12\x84\x01\n\x1dUpdateLogicalDeviceMeterTable\x12\x1b.openflow_13.MeterModUpdate\x1a\x16.google.protobuf.Empty\".\x82\xd3\xe4\x93\x02(\"#/api/v1/logical_devices/{id}/meters:\x01*\x12g\n\x17ListLogicalDeviceMeters\x12\n.common.ID\x1a\x13.openflow_13.Meters\"+\x82\xd3\xe4\x93\x02%\x12#/api/v1/logical_devices/{id}/meters\x12t\n\x1bListLogicalDeviceFlowGroups\x12\n.common.ID\x1a\x17.openflow_13.FlowGroups\"0\x82\xd3\xe4\x93\x02*\x12(/api/v1/logical_devices/{id}/flow_groups\x12\x93\x01\n!UpdateLogicalDeviceFlowGroupTable\x12!.openflow_13.FlowGroupTableUpdate\x1a\x16.google.protobuf.Empty\"3\x82\xd3\xe4\x93\x02-\"(/api/v1/logical_devices/{id}/flow_groups:\x01*\x12O\n\x0bListDevices\x12\x16.google.protobuf.Empty\x1a\x0f.device.Devices\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/api/v1/devices\x12O\n\rListDeviceIds\x12\x16.google.protobuf.Empty\x1a\x0b.common.IDs\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/api/v1/deviceids\x12U\n\x10ReconcileDevices\x12\x0b.common.IDs\x1a\x16.google.protobuf.Empty\"\x1c\x82\xd3\xe4\x93\x02\x16\"\x11/api/v1/deviceids:\x01*\x12\x45\n\tGetDevice\x12\n.common.ID\x1a\x0e.device.Device\"\x1c\x82\xd3\xe4\x93\x02\x16\x12\x14/api/v1/devices/{id}\x12J\n\x0c\x43reateDevice\x12\x0e.device.Device\x1a\x0e.device.Device\"\x1a\x82\xd3\xe4\x93\x02\x14\"\x0f/api/v1/devices:\x01*\x12W\n\x0c\x45nableDevice\x12\n.common.ID\x1a\x16.google.protobuf.Empty\"#\x82\xd3\xe4\x93\x02\x1d\"\x1b/api/v1/devices/{id}/enable\x12Y\n\rDisableDevice\x12\n.common.ID\x1a\x16.google.protobuf.Empty\"$\x82\xd3\xe4\x93\x02\x1e\"\x1c/api/v1/devices/{id}/disable\x12W\n\x0cRebootDevice\x12\n.common.ID\x1a\x16.google.protobuf.Empty\"#\x82\xd3\xe4\x93\x02\x1d\"\x1b/api/v1/devices/{id}/reboot\x12W\n\x0c\x44\x65leteDevice\x12\n.common.ID\x1a\x16.google.protobuf.Empty\"#\x82\xd3\xe4\x93\x02\x1d*\x1b/api/v1/devices/{id}/delete\x12\x62\n\x11\x46orceDeleteDevice\x12\n.common.ID\x1a\x16.google.protobuf.Empty\")\x82\xd3\xe4\x93\x02#*!/api/v1/devices/{id}/force_delete\x12x\n\rDownloadImage\x12\x15.device.ImageDownload\x1a\x15.common.OperationResp\"9\x88\x02\x01\x82\xd3\xe4\x93\x02\x30\"+/api/v1/devices/{id}/image_downloads/{name}:\x01*\x12\x85\x01\n\x16GetImageDownloadStatus\x12\x15.device.ImageDownload\x1a\x15.device.ImageDownload\"=\x88\x02\x01\x82\xd3\xe4\x93\x02\x34\x12\x32/api/v1/devices/{id}/image_downloads/{name}/status\x12x\n\x10GetImageDownload\x12\x15.device.ImageDownload\x1a\x15.device.ImageDownload\"6\x88\x02\x01\x82\xd3\xe4\x93\x02-\x12+/api/v1/devices/{id}/image_downloads/{name}\x12i\n\x12ListImageDownloads\x12\n.common.ID\x1a\x16.device.ImageDownloads\"/\x88\x02\x01\x82\xd3\xe4\x93\x02&\x12$/api/v1/devices/{id}/image_downloads\x12{\n\x13\x43\x61ncelImageDownload\x12\x15.device.ImageDownload\x1a\x15.common.OperationResp\"6\x88\x02\x01\x82\xd3\xe4\x93\x02-*+/api/v1/devices/{id}/image_downloads/{name}\x12\x8b\x01\n\x13\x41\x63tivateImageUpdate\x12\x15.device.ImageDownload\x1a\x15.common.OperationResp\"F\x88\x02\x01\x82\xd3\xe4\x93\x02=\"8/api/v1/devices/{id}/image_downloads/{name}/image_update:\x01*\x12\x89\x01\n\x11RevertImageUpdate\x12\x15.device.ImageDownload\x1a\x15.common.OperationResp\"F\x88\x02\x01\x82\xd3\xe4\x93\x02=\"8/api/v1/devices/{id}/image_downloads/{name}/image_revert:\x01*\x12\x88\x01\n\x15\x44ownloadImageToDevice\x12\".device.DeviceImageDownloadRequest\x1a\x1b.device.DeviceImageResponse\".\x82\xd3\xe4\x93\x02(\x12&/api/v1/devices/images/download_images\x12w\n\x0eGetImageStatus\x12\x1a.device.DeviceImageRequest\x1a\x1b.device.DeviceImageResponse\",\x82\xd3\xe4\x93\x02&\x12$/api/v1/devices/images/images_status\x12\x89\x01\n\x19\x41\x62ortImageUpgradeToDevice\x12\x1a.device.DeviceImageRequest\x1a\x1b.device.DeviceImageResponse\"3\x82\xd3\xe4\x93\x02-\x12+/api/v1/devices/images/abort_upgrade_images\x12V\n\x0cGetOnuImages\x12\n.common.ID\x1a\x11.device.OnuImages\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/api/v1/devices/{id}/onu_images\x12{\n\rActivateImage\x12\x1a.device.DeviceImageRequest\x1a\x1b.device.DeviceImageResponse\"1\x82\xd3\xe4\x93\x02+\"&/api/v1/devices/images/activate_images:\x01*\x12w\n\x0b\x43ommitImage\x12\x1a.device.DeviceImageRequest\x1a\x1b.device.DeviceImageResponse\"/\x82\xd3\xe4\x93\x02)\"$/api/v1/devices/images/commit_images:\x01*\x12P\n\x0fListDevicePorts\x12\n.common.ID\x1a\r.device.Ports\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/api/v1/devices/{id}/ports\x12]\n\x13ListDevicePmConfigs\x12\n.common.ID\x1a\x11.device.PmConfigs\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/api/v1/devices/{id}/pm_configs\x12n\n\x15UpdateDevicePmConfigs\x12\x11.device.PmConfigs\x1a\x16.google.protobuf.Empty\"*\x82\xd3\xe4\x93\x02$\"\x1f/api/v1/devices/{id}/pm_configs:\x01*\x12U\n\x0fListDeviceFlows\x12\n.common.ID\x1a\x12.openflow_13.Flows\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/api/v1/devices/{id}/flows\x12\x65\n\x14ListDeviceFlowGroups\x12\n.common.ID\x1a\x17.openflow_13.FlowGroups\"(\x82\xd3\xe4\x93\x02\"\x12 /api/v1/devices/{id}/flow_groups\x12\\\n\x0fListDeviceTypes\x12\x16.google.protobuf.Empty\x1a\x13.device.DeviceTypes\"\x1c\x82\xd3\xe4\x93\x02\x16\x12\x14/api/v1/device_types\x12R\n\rGetDeviceType\x12\n.common.ID\x1a\x12.device.DeviceType\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/api/v1/device_types/{id}\x12\x46\n\x10StreamPacketsOut\x12\x16.openflow_13.PacketOut\x1a\x16.google.protobuf.Empty\"\x00(\x01\x12\x45\n\x10ReceivePacketsIn\x12\x16.google.protobuf.Empty\x1a\x15.openflow_13.PacketIn\"\x00\x30\x01\x12K\n\x13ReceiveChangeEvents\x12\x16.google.protobuf.Empty\x1a\x18.openflow_13.ChangeEvent\"\x00\x30\x01\x12]\n\x11\x43reateEventFilter\x12\x12.event.EventFilter\x1a\x12.event.EventFilter\" \x82\xd3\xe4\x93\x02\x1a\"\x15/api/v1/event_filters:\x01*\x12U\n\x0eGetEventFilter\x12\n.common.ID\x1a\x13.event.EventFilters\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/api/v1/event_filters/{id}\x12\x62\n\x11UpdateEventFilter\x12\x12.event.EventFilter\x1a\x12.event.EventFilter\"%\x82\xd3\xe4\x93\x02\x1f\x1a\x1a/api/v1/event_filters/{id}:\x01*\x12\x63\n\x11\x44\x65leteEventFilter\x12\x12.event.EventFilter\x1a\x16.google.protobuf.Empty\"\"\x82\xd3\xe4\x93\x02\x1c*\x1a/api/v1/event_filters/{id}\x12^\n\x10ListEventFilters\x12\x16.google.protobuf.Empty\x1a\x13.event.EventFilters\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/api/v1/event_filters\x12L\n\tGetImages\x12\n.common.ID\x1a\x0e.device.Images\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/api/v1/devices/{id}/images\x12X\n\x08SelfTest\x12\n.common.ID\x1a\x18.device.SelfTestResponse\"&\x82\xd3\xe4\x93\x02 \"\x1e/api/v1/devices/{id}/self_test\x12V\n\x10GetMibDeviceData\x12\n.common.ID\x1a\x13.omci.MibDeviceData\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/api/v1/openomci/{id}/mib\x12\\\n\x12GetAlarmDeviceData\x12\n.common.ID\x1a\x15.omci.AlarmDeviceData\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/api/v1/openomci/{id}/alarm\x12s\n\rSimulateAlarm\x12\x1c.device.SimulateAlarmRequest\x1a\x15.common.OperationResp\"-\x82\xd3\xe4\x93\x02\'\"\"/api/v1/devices/{id}/simulate_larm:\x01*\x12M\n\nEnablePort\x12\x0c.device.Port\x1a\x16.google.protobuf.Empty\"\x19\x82\xd3\xe4\x93\x02\x13\"\x0e/v1/EnablePort:\x01*\x12O\n\x0b\x44isablePort\x12\x0c.device.Port\x1a\x16.google.protobuf.Empty\"\x1a\x82\xd3\xe4\x93\x02\x14\"\x0f/v1/DisablePort:\x01*\x12^\n\x0bGetExtValue\x12\x19.extension.ValueSpecifier\x1a\x17.extension.ReturnValues\"\x1b\x82\xd3\xe4\x93\x02\x15\x12\x13/api/v1/GetExtValue\x12W\n\x0bSetExtValue\x12\x13.extension.ValueSet\x1a\x16.google.protobuf.Empty\"\x1b\x82\xd3\xe4\x93\x02\x15\x12\x13/api/v1/SetExtValue\x12\x64\n\x13StartOmciTestAction\x12\x15.omci.OmciTestRequest\x1a\x12.omci.TestResponse\"\"\x82\xd3\xe4\x93\x02\x1c\"\x17/api/v1/start_omci_test:\x01*\x12\x85\x01\n\x14PutVoipSystemProfile\x12-.voip_system_profile.VoipSystemProfileRequest\x1a\x16.google.protobuf.Empty\"&\x82\xd3\xe4\x93\x02 \"\x1b/api/v1/voip_system_profile:\x01*\x12p\n\x17\x44\x65leteVoipSystemProfile\x12\x0b.common.Key\x1a\x16.google.protobuf.Empty\"0\x82\xd3\xe4\x93\x02**(/api/v1/voip_system_profile/{key}/delete\x12}\n\x12PutVoipUserProfile\x12).voip_user_profile.VoipUserProfileRequest\x1a\x16.google.protobuf.Empty\"$\x82\xd3\xe4\x93\x02\x1e\"\x19/api/v1/voip_user_profile:\x01*\x12l\n\x15\x44\x65leteVoipUserProfile\x12\x0b.common.Key\x1a\x16.google.protobuf.Empty\".\x82\xd3\xe4\x93\x02(*&/api/v1/voip_user_profile/{key}/delete\x12Z\n\x10\x44isableOnuDevice\x12\n.common.ID\x1a\x16.google.protobuf.Empty\"\"\x82\xd3\xe4\x93\x02\x1c\"\x1a/api/v1/disable_onu_device\x12X\n\x0f\x45nableOnuDevice\x12\n.common.ID\x1a\x16.google.protobuf.Empty\"!\x82\xd3\xe4\x93\x02\x1b\"\x19/api/v1/enable_onu_device\x12|\n\x16\x44isableOnuSerialNumber\x12\x1f.device.OnuSerialNumberOnOLTPon\x1a\x16.google.protobuf.Empty\")\x82\xd3\xe4\x93\x02#\"!/api/v1/disable_onu_serial_number\x12z\n\x15\x45nableOnuSerialNumber\x12\x1f.device.OnuSerialNumberOnOLTPon\x1a\x16.google.protobuf.Empty\"(\x82\xd3\xe4\x93\x02\"\" /api/v1/enable_onu_serial_number\x12[\n\x0cUpdateDevice\x12\x14.device.UpdateDevice\x1a\x16.google.protobuf.Empty\"\x1d\x82\xd3\xe4\x93\x02\x17\"\x15/api/v1/update_deviceBl\n\x13org.opencord.volthaB\x0cVolthaProtosZ.github.com/opencord/voltha-protos/v5/go/voltha\xaa\x02\x16Opencord.Voltha.VolthaP\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'voltha_protos.voltha_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\023org.opencord.volthaB\014VolthaProtosZ.github.com/opencord/voltha-protos/v5/go/voltha\252\002\026Opencord.Voltha.Voltha'
  _globals['_VOLTHASERVICE'].methods_by_name['GetVoltha']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['GetVoltha']._serialized_options = b'\202\323\344\223\002\t\022\007/api/v1'
  _globals['_VOLTHASERVICE'].methods_by_name['ListCoreInstances']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['ListCoreInstances']._serialized_options = b'\202\323\344\223\002\023\022\021/api/v1/instances'
  _globals['_VOLTHASERVICE'].methods_by_name['GetCoreInstance']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['GetCoreInstance']._serialized_options = b'\202\323\344\223\002\030\022\026/api/v1/instances/{id}'
  _globals['_VOLTHASERVICE'].methods_by_name['ListAdapters']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['ListAdapters']._serialized_options = b'\202\323\344\223\002\022\022\020/api/v1/adapters'
  _globals['_VOLTHASERVICE'].methods_by_name['ListLogicalDevices']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['ListLogicalDevices']._serialized_options = b'\202\323\344\223\002\031\022\027/api/v1/logical_devices'
  _globals['_VOLTHASERVICE'].methods_by_name['GetLogicalDevice']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['GetLogicalDevice']._serialized_options = b'\202\323\344\223\002\036\022\034/api/v1/logical_devices/{id}'
  _globals['_VOLTHASERVICE'].methods_by_name['ListLogicalDevicePorts']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['ListLogicalDevicePorts']._serialized_options = b'\202\323\344\223\002$\022\"/api/v1/logical_devices/{id}/ports'
  _globals['_VOLTHASERVICE'].methods_by_name['GetLogicalDevicePort']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['GetLogicalDevicePort']._serialized_options = b'\202\323\344\223\002.\022,/api/v1/logical_devices/{id}/ports/{port_id}'
  _globals['_VOLTHASERVICE'].methods_by_name['EnableLogicalDevicePort']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['EnableLogicalDevicePort']._serialized_options = b'\202\323\344\223\0025\"3/api/v1/logical_devices/{id}/ports/{port_id}/enable'
  _globals['_VOLTHASERVICE'].methods_by_name['DisableLogicalDevicePort']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['DisableLogicalDevicePort']._serialized_options = b'\202\323\344\223\0026\"4/api/v1/logical_devices/{id}/ports/{port_id}/disable'
  _globals['_VOLTHASERVICE'].methods_by_name['ListLogicalDeviceFlows']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['ListLogicalDeviceFlows']._serialized_options = b'\202\323\344\223\002$\022\"/api/v1/logical_devices/{id}/flows'
  _globals['_VOLTHASERVICE'].methods_by_name['UpdateLogicalDeviceFlowTable']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['UpdateLogicalDeviceFlowTable']._serialized_options = b'\202\323\344\223\002\'\"\"/api/v1/logical_devices/{id}/flows:\001*'
  _globals['_VOLTHASERVICE'].methods_by_name['UpdateLogicalDeviceMeterTable']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['UpdateLogicalDeviceMeterTable']._serialized_options = b'\202\323\344\223\002(\"#/api/v1/logical_devices/{id}/meters:\001*'
  _globals['_VOLTHASERVICE'].methods_by_name['ListLogicalDeviceMeters']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['ListLogicalDeviceMeters']._serialized_options = b'\202\323\344\223\002%\022#/api/v1/logical_devices/{id}/meters'
  _globals['_VOLTHASERVICE'].methods_by_name['ListLogicalDeviceFlowGroups']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['ListLogicalDeviceFlowGroups']._serialized_options = b'\202\323\344\223\002*\022(/api/v1/logical_devices/{id}/flow_groups'
  _globals['_VOLTHASERVICE'].methods_by_name['UpdateLogicalDeviceFlowGroupTable']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['UpdateLogicalDeviceFlowGroupTable']._serialized_options = b'\202\323\344\223\002-\"(/api/v1/logical_devices/{id}/flow_groups:\001*'
  _globals['_VOLTHASERVICE'].methods_by_name['ListDevices']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['ListDevices']._serialized_options = b'\202\323\344\223\002\021\022\017/api/v1/devices'
  _globals['_VOLTHASERVICE'].methods_by_name['ListDeviceIds']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['ListDeviceIds']._serialized_options = b'\202\323\344\223\002\023\022\021/api/v1/deviceids'
  _globals['_VOLTHASERVICE'].methods_by_name['ReconcileDevices']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['ReconcileDevices']._serialized_options = b'\202\323\344\223\002\026\"\021/api/v1/deviceids:\001*'
  _globals['_VOLTHASERVICE'].methods_by_name['GetDevice']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['GetDevice']._serialized_options = b'\202\323\344\223\002\026\022\024/api/v1/devices/{id}'
  _globals['_VOLTHASERVICE'].methods_by_name['CreateDevice']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['CreateDevice']._serialized_options = b'\202\323\344\223\002\024\"\017/api/v1/devices:\001*'
  _globals['_VOLTHASERVICE'].methods_by_name['EnableDevice']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['EnableDevice']._serialized_options = b'\202\323\344\223\002\035\"\033/api/v1/devices/{id}/enable'
  _globals['_VOLTHASERVICE'].methods_by_name['DisableDevice']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['DisableDevice']._serialized_options = b'\202\323\344\223\002\036\"\034/api/v1/devices/{id}/disable'
  _globals['_VOLTHASERVICE'].methods_by_name['RebootDevice']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['RebootDevice']._serialized_options = b'\202\323\344\223\002\035\"\033/api/v1/devices/{id}/reboot'
  _globals['_VOLTHASERVICE'].methods_by_name['DeleteDevice']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['DeleteDevice']._serialized_options = b'\202\323\344\223\002\035*\033/api/v1/devices/{id}/delete'
  _globals['_VOLTHASERVICE'].methods_by_name['ForceDeleteDevice']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['ForceDeleteDevice']._serialized_options = b'\202\323\344\223\002#*!/api/v1/devices/{id}/force_delete'
  _globals['_VOLTHASERVICE'].methods_by_name['DownloadImage']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['DownloadImage']._serialized_options = b'\210\002\001\202\323\344\223\0020\"+/api/v1/devices/{id}/image_downloads/{name}:\001*'
  _globals['_VOLTHASERVICE'].methods_by_name['GetImageDownloadStatus']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['GetImageDownloadStatus']._serialized_options = b'\210\002\001\202\323\344\223\0024\0222/api/v1/devices/{id}/image_downloads/{name}/status'
  _globals['_VOLTHASERVICE'].methods_by_name['GetImageDownload']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['GetImageDownload']._serialized_options = b'\210\002\001\202\323\344\223\002-\022+/api/v1/devices/{id}/image_downloads/{name}'
  _globals['_VOLTHASERVICE'].methods_by_name['ListImageDownloads']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['ListImageDownloads']._serialized_options = b'\210\002\001\202\323\344\223\002&\022$/api/v1/devices/{id}/image_downloads'
  _globals['_VOLTHASERVICE'].methods_by_name['CancelImageDownload']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['CancelImageDownload']._serialized_options = b'\210\002\001\202\323\344\223\002-*+/api/v1/devices/{id}/image_downloads/{name}'
  _globals['_VOLTHASERVICE'].methods_by_name['ActivateImageUpdate']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['ActivateImageUpdate']._serialized_options = b'\210\002\001\202\323\344\223\002=\"8/api/v1/devices/{id}/image_downloads/{name}/image_update:\001*'
  _globals['_VOLTHASERVICE'].methods_by_name['RevertImageUpdate']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['RevertImageUpdate']._serialized_options = b'\210\002\001\202\323\344\223\002=\"8/api/v1/devices/{id}/image_downloads/{name}/image_revert:\001*'
  _globals['_VOLTHASERVICE'].methods_by_name['DownloadImageToDevice']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['DownloadImageToDevice']._serialized_options = b'\202\323\344\223\002(\022&/api/v1/devices/images/download_images'
  _globals['_VOLTHASERVICE'].methods_by_name['GetImageStatus']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['GetImageStatus']._serialized_options = b'\202\323\344\223\002&\022$/api/v1/devices/images/images_status'
  _globals['_VOLTHASERVICE'].methods_by_name['AbortImageUpgradeToDevice']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['AbortImageUpgradeToDevice']._serialized_options = b'\202\323\344\223\002-\022+/api/v1/devices/images/abort_upgrade_images'
  _globals['_VOLTHASERVICE'].methods_by_name['GetOnuImages']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['GetOnuImages']._serialized_options = b'\202\323\344\223\002!\022\037/api/v1/devices/{id}/onu_images'
  _globals['_VOLTHASERVICE'].methods_by_name['ActivateImage']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['ActivateImage']._serialized_options = b'\202\323\344\223\002+\"&/api/v1/devices/images/activate_images:\001*'
  _globals['_VOLTHASERVICE'].methods_by_name['CommitImage']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['CommitImage']._serialized_options = b'\202\323\344\223\002)\"$/api/v1/devices/images/commit_images:\001*'
  _globals['_VOLTHASERVICE'].methods_by_name['ListDevicePorts']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['ListDevicePorts']._serialized_options = b'\202\323\344\223\002\034\022\032/api/v1/devices/{id}/ports'
  _globals['_VOLTHASERVICE'].methods_by_name['ListDevicePmConfigs']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['ListDevicePmConfigs']._serialized_options = b'\202\323\344\223\002!\022\037/api/v1/devices/{id}/pm_configs'
  _globals['_VOLTHASERVICE'].methods_by_name['UpdateDevicePmConfigs']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['UpdateDevicePmConfigs']._serialized_options = b'\202\323\344\223\002$\"\037/api/v1/devices/{id}/pm_configs:\001*'
  _globals['_VOLTHASERVICE'].methods_by_name['ListDeviceFlows']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['ListDeviceFlows']._serialized_options = b'\202\323\344\223\002\034\022\032/api/v1/devices/{id}/flows'
  _globals['_VOLTHASERVICE'].methods_by_name['ListDeviceFlowGroups']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['ListDeviceFlowGroups']._serialized_options = b'\202\323\344\223\002\"\022 /api/v1/devices/{id}/flow_groups'
  _globals['_VOLTHASERVICE'].methods_by_name['ListDeviceTypes']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['ListDeviceTypes']._serialized_options = b'\202\323\344\223\002\026\022\024/api/v1/device_types'
  _globals['_VOLTHASERVICE'].methods_by_name['GetDeviceType']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['GetDeviceType']._serialized_options = b'\202\323\344\223\002\033\022\031/api/v1/device_types/{id}'
  _globals['_VOLTHASERVICE'].methods_by_name['CreateEventFilter']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['CreateEventFilter']._serialized_options = b'\202\323\344\223\002\032\"\025/api/v1/event_filters:\001*'
  _globals['_VOLTHASERVICE'].methods_by_name['GetEventFilter']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['GetEventFilter']._serialized_options = b'\202\323\344\223\002\034\022\032/api/v1/event_filters/{id}'
  _globals['_VOLTHASERVICE'].methods_by_name['UpdateEventFilter']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['UpdateEventFilter']._serialized_options = b'\202\323\344\223\002\037\032\032/api/v1/event_filters/{id}:\001*'
  _globals['_VOLTHASERVICE'].methods_by_name['DeleteEventFilter']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['DeleteEventFilter']._serialized_options = b'\202\323\344\223\002\034*\032/api/v1/event_filters/{id}'
  _globals['_VOLTHASERVICE'].methods_by_name['ListEventFilters']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['ListEventFilters']._serialized_options = b'\202\323\344\223\002\027\022\025/api/v1/event_filters'
  _globals['_VOLTHASERVICE'].methods_by_name['GetImages']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['GetImages']._serialized_options = b'\202\323\344\223\002\035\022\033/api/v1/devices/{id}/images'
  _globals['_VOLTHASERVICE'].methods_by_name['SelfTest']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['SelfTest']._serialized_options = b'\202\323\344\223\002 \"\036/api/v1/devices/{id}/self_test'
  _globals['_VOLTHASERVICE'].methods_by_name['GetMibDeviceData']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['GetMibDeviceData']._serialized_options = b'\202\323\344\223\002\033\022\031/api/v1/openomci/{id}/mib'
  _globals['_VOLTHASERVICE'].methods_by_name['GetAlarmDeviceData']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['GetAlarmDeviceData']._serialized_options = b'\202\323\344\223\002\035\022\033/api/v1/openomci/{id}/alarm'
  _globals['_VOLTHASERVICE'].methods_by_name['SimulateAlarm']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['SimulateAlarm']._serialized_options = b'\202\323\344\223\002\'\"\"/api/v1/devices/{id}/simulate_larm:\001*'
  _globals['_VOLTHASERVICE'].methods_by_name['EnablePort']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['EnablePort']._serialized_options = b'\202\323\344\223\002\023\"\016/v1/EnablePort:\001*'
  _globals['_VOLTHASERVICE'].methods_by_name['DisablePort']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['DisablePort']._serialized_options = b'\202\323\344\223\002\024\"\017/v1/DisablePort:\001*'
  _globals['_VOLTHASERVICE'].methods_by_name['GetExtValue']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['GetExtValue']._serialized_options = b'\202\323\344\223\002\025\022\023/api/v1/GetExtValue'
  _globals['_VOLTHASERVICE'].methods_by_name['SetExtValue']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['SetExtValue']._serialized_options = b'\202\323\344\223\002\025\022\023/api/v1/SetExtValue'
  _globals['_VOLTHASERVICE'].methods_by_name['StartOmciTestAction']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['StartOmciTestAction']._serialized_options = b'\202\323\344\223\002\034\"\027/api/v1/start_omci_test:\001*'
  _globals['_VOLTHASERVICE'].methods_by_name['PutVoipSystemProfile']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['PutVoipSystemProfile']._serialized_options = b'\202\323\344\223\002 \"\033/api/v1/voip_system_profile:\001*'
  _globals['_VOLTHASERVICE'].methods_by_name['DeleteVoipSystemProfile']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['DeleteVoipSystemProfile']._serialized_options = b'\202\323\344\223\002**(/api/v1/voip_system_profile/{key}/delete'
  _globals['_VOLTHASERVICE'].methods_by_name['PutVoipUserProfile']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['PutVoipUserProfile']._serialized_options = b'\202\323\344\223\002\036\"\031/api/v1/voip_user_profile:\001*'
  _globals['_VOLTHASERVICE'].methods_by_name['DeleteVoipUserProfile']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['DeleteVoipUserProfile']._serialized_options = b'\202\323\344\223\002(*&/api/v1/voip_user_profile/{key}/delete'
  _globals['_VOLTHASERVICE'].methods_by_name['DisableOnuDevice']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['DisableOnuDevice']._serialized_options = b'\202\323\344\223\002\034\"\032/api/v1/disable_onu_device'
  _globals['_VOLTHASERVICE'].methods_by_name['EnableOnuDevice']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['EnableOnuDevice']._serialized_options = b'\202\323\344\223\002\033\"\031/api/v1/enable_onu_device'
  _globals['_VOLTHASERVICE'].methods_by_name['DisableOnuSerialNumber']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['DisableOnuSerialNumber']._serialized_options = b'\202\323\344\223\002#\"!/api/v1/disable_onu_serial_number'
  _globals['_VOLTHASERVICE'].methods_by_name['EnableOnuSerialNumber']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['EnableOnuSerialNumber']._serialized_options = b'\202\323\344\223\002\"\" /api/v1/enable_onu_serial_number'
  _globals['_VOLTHASERVICE'].methods_by_name['UpdateDevice']._options = None
  _globals['_VOLTHASERVICE'].methods_by_name['UpdateDevice']._serialized_options = b'\202\323\344\223\002\027\"\025/api/v1/update_device'
  _globals['_COREINSTANCE']._serialized_start=518
  _globals['_COREINSTANCE']._serialized_end=591
  _globals['_COREINSTANCES']._serialized_start=593
  _globals['_COREINSTANCES']._serialized_end=645
  _globals['_VOLTHA']._serialized_start=648
  _globals['_VOLTHA']._serialized_end=989
  _globals['_VOLTHASERVICE']._serialized_start=992
  _globals['_VOLTHASERVICE']._serialized_end=8603
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: voltha_protos/health.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1avoltha_protos/health.proto\x12\x06health\x1a\x1cgoogle/api/annotations.proto\x1a\x1bgoogle/protobuf/empty.proto\"v\n\x0cHealthStatus\x12/\n\x05state\x18\x01 \x01(\x0e\x32 .health.HealthStatus.HealthState\"5\n\x0bHealthState\x12\x0b\n\x07HEALTHY\x10\x00\x12\x0e\n\nOVERLOADED\x10\x01\x12\t\n\x05\x44YING\x10\x02\x32\x61\n\rHealthService\x12P\n\x0fGetHealthStatus\x12\x16.google.protobuf.Empty\x1a\x14.health.HealthStatus\"\x0f\x82\xd3\xe4\x93\x02\t\x12\x07/healthBL\n\x1aorg.opencord.voltha.healthZ.github.com/opencord/voltha-protos/v5/go/healthb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'voltha_protos.health_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\032org.opencord.voltha.healthZ.github.com/opencord/voltha-protos/v5/go/health'
  _globals['_HEALTHSERVICE'].methods_by_name['GetHealthStatus']._options = None
  _globals['_HEALTHSERVICE'].methods_by_name['GetHealthStatus']._serialized_options = b'\202\323\344\223\002\t\022\007/health'
  _globals['_HEALTHSTATUS']._serialized_start=97
  _globals['_HEALTHSTATUS']._serialized_end=215
  _globals['_HEALTHSTATUS_HEALTHSTATE']._serialized_start=162
  _globals['_HEALTHSTATUS_HEALTHSTATE']._serialized_end=215
  _globals['_HEALTHSERVICE']._serialized_start=217
  _globals['_HEALTHSERVICE']._serialized_end=314
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: voltha_protos/ietf_interfaces.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#voltha_protos/ietf_interfaces.proto\x12\x04ietf\"5\n\nInterfaces\x12\'\n\x0e\x61ll_interfaces\x18\x01 \x03(\x0b\x32\x0f.ietf.Interface\"\xda\x01\n\tInterface\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x04 \x01(\x08\x12J\n\x18link_up_down_trap_enable\x18\x05 \x01(\x0e\x32(.ietf.Interface.LinkUpDownTrapEnableType\"?\n\x18LinkUpDownTrapEnableType\x12\x11\n\rTRAP_DISABLED\x10\x00\x12\x10\n\x0cTRAP_ENABLED\x10\x01\">\n\x0fInterfacesState\x12+\n\rall_interfacs\x18\x01 \x03(\x0b\x32\x14.ietf.InterfaceState\"\xd5\x03\n\x0eInterfaceState\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12:\n\x0c\x61\x64min_status\x18\x03 \x01(\x0e\x32$.ietf.InterfaceState.AdminStatusType\x12\x38\n\x0boper_status\x18\x04 \x01(\x0e\x32#.ietf.InterfaceState.OperStatusType\x12\x13\n\x0blast_change\x18\x05 \x01(\t\x12\x10\n\x08if_index\x18\x06 \x01(\x05\x12\x14\n\x0cphys_address\x18\x07 \x01(\t\x12\x17\n\x0fhigher_layer_if\x18\x08 \x03(\t\x12\x16\n\x0elower_layer_if\x18\t \x03(\t\x12\r\n\x05speed\x18\n \x01(\x04\"B\n\x0f\x41\x64minStatusType\x12\x0e\n\nADMIN_DOWN\x10\x00\x12\x11\n\rADMIN_TESTING\x10\x01\x12\x0c\n\x08\x41\x44MIN_UP\x10\x02\"p\n\x0eOperStatusType\x12\x0b\n\x07\x44ORMANT\x10\x00\x12\x14\n\x10LOWER_LAYER_DOWN\x10\x01\x12\x0b\n\x07UNKNOWN\x10\x02\x12\x0b\n\x07TESTING\x10\x03\x12\x06\n\x02UP\x10\x04\x12\x08\n\x04\x44OWN\x10\x05\x12\x0f\n\x0bNOT_PRESENT\x10\x06\x42H\n\x18org.opencord.voltha.ietfZ,github.com/opencord/voltha-protos/v5/go/ietfb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'voltha_protos.ietf_interfaces_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\030org.opencord.voltha.ietfZ,github.com/opencord/voltha-protos/v5/go/ietf'
  _globals['_INTERFACES']._serialized_start=45
  _globals['_INTERFACES']._serialized_end=98
  _globals['_INTERFACE']._serialized_start=101
  _globals['_INTERFACE']._serialized_end=319
  _globals['_INTERFACE_LINKUPDOWNTRAPENABLETYPE']._serialized_start=256
  _globals['_INTERFACE_LINKUPDOWNTRAPENABLETYPE']._serialized_end=319
  _globals['_INTERFACESSTATE']._serialized_start=321
  _globals['_INTERFACESSTATE']._serialized_end=383
  _globals['_INTERFACESTATE']._serialized_start=386
  _globals['_INTERFACESTATE']._serialized_end=855
  _globals['_INTERFACESTATE_ADMINSTATUSTYPE']._serialized_start=675
  _globals['_INTERFACESTATE_ADMINSTATUSTYPE']._serialized_end=741
  _globals['_INTERFACESTATE_OPERSTATUSTYPE']._serialized_start=743
  _globals['_INTERFACESTATE_OPERSTATUSTYPE']._serialized_end=855
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: voltha_protos/adapter.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bvoltha_protos/adapter.proto\x12\x07\x61\x64\x61pter\x1a\x19google/protobuf/any.proto\"@\n\rAdapterConfig\x12/\n\x11\x61\x64\x64itional_config\x18@ \x01(\x0b\x32\x14.google.protobuf.Any\"\x9b\x02\n\x07\x41\x64\x61pter\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06vendor\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t\x12&\n\x06\x63onfig\x18\x10 \x01(\x0b\x32\x16.adapter.AdapterConfig\x12\x34\n\x16\x61\x64\x64itional_description\x18@ \x01(\x0b\x32\x14.google.protobuf.Any\x12\x1a\n\x12logical_device_ids\x18\x04 \x03(\t\x12\x1a\n\x12last_communication\x18\x05 \x01(\x03\x12\x16\n\x0e\x63urrentReplica\x18\x06 \x01(\x05\x12\x15\n\rtotalReplicas\x18\x07 \x01(\x05\x12\x10\n\x08\x65ndpoint\x18\x08 \x01(\t\x12\x0c\n\x04type\x18\t \x01(\t\"+\n\x08\x41\x64\x61pters\x12\x1f\n\x05items\x18\x01 \x03(\x0b\x32\x10.adapter.AdapterB\\\n\x1borg.opencord.voltha.adapterB\rVolthaAdapterZ.github.com/opencord/voltha-protos/v5/go/volthab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'voltha_protos.adapter_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033org.opencord.voltha.adapterB\rVolthaAdapterZ.github.com/opencord/voltha-protos/v5/go/voltha'
  _globals['_ADAPTERCONFIG']._serialized_start=67
  _globals['_ADAPTERCONFIG']._serialized_end=131
  _globals['_ADAPTER']._serialized_start=134
  _globals['_ADAPTER']._serialized_end=417
  _globals['_ADAPTERS']._serialized_start=419
  _globals['_ADAPTERS']._serialized_end=462
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: voltha_protos/onu_inter_adapter_service.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from voltha_protos import common_pb2 as voltha__protos_dot_common__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from voltha_protos import inter_adapter_pb2 as voltha__protos_dot_inter__adapter__pb2
from voltha_protos import health_pb2 as voltha__protos_dot_health__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-voltha_protos/onu_inter_adapter_service.proto\x12\x19onu_inter_adapter_service\x1a\x1avoltha_protos/common.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a!voltha_protos/inter_adapter.proto\x1a\x1avoltha_protos/health.proto2\xdf\x03\n\x16OnuInterAdapterService\x12?\n\x0fGetHealthStatus\x12\x12.common.Connection\x1a\x14.health.HealthStatus(\x01\x30\x01\x12L\n\rOnuIndication\x12#.inter_adapter.OnuIndicationMessage\x1a\x16.google.protobuf.Empty\x12\x44\n\x0eOmciIndication\x12\x1a.inter_adapter.OmciMessage\x1a\x16.google.protobuf.Empty\x12X\n\x13\x44ownloadTechProfile\x12).inter_adapter.TechProfileDownloadMessage\x1a\x16.google.protobuf.Empty\x12L\n\rDeleteGemPort\x12#.inter_adapter.DeleteGemPortMessage\x1a\x16.google.protobuf.Empty\x12H\n\x0b\x44\x65leteTCont\x12!.inter_adapter.DeleteTcontMessage\x1a\x16.google.protobuf.EmptyB\x90\x01\n-org.opencord.voltha.onu_inter_adapter_serviceB\x1cVolthaOnuInterAdapterServiceZAgithub.com/opencord/voltha-protos/v5/go/onu_inter_adapter_serviceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'voltha_protos.onu_inter_adapter_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n-org.opencord.voltha.onu_inter_adapter_serviceB\034VolthaOnuInterAdapterServiceZAgithub.com/opencord/voltha-protos/v5/go/onu_inter_adapter_service'
  _globals['_ONUINTERADAPTERSERVICE']._serialized_start=197
  _globals['_ONUINTERADAPTERSERVICE']._serialized_end=676
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# -----------------------------------------------------------------------
# Copyright 2019-2024 Open Networking Foundation Contributors
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# -----------------------------------------------------------------------
# SPDX-FileCopyrightText: 2019-2024 Open Networking Foundation Contributors
# SPDX-License-Identifier: Apache-2.0
# -----------------------------------------------------------------------

from setuptools import setup, find_packages


def version():
    with open('VERSION') as f:
        return f.read()


setup(
    name='voltha-protos',
    version=version(),
    description='Protobuf interface definitions',
    author='VOLTHA project',
    author_email='voltha-dev@opencord.org',
    url='https://gerrit.opencord.org/gitweb?p=voltha-protos.git',
    license='Apache Software License',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: Apache Software License',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
    ],
    keywords='protobuf voltha',
    packages = find_packages(where="python"),
    package_dir = {"": "python"},
    install_requires = [
        "grpcio>=1.60.0",
        "protobuf>=4.25.0",
        "grpcio-tools>=1.60.0",
        "googleapis-common-protos==1.56.4"
    ],
    include_package_data=True,
)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: voltha_protos/logical_device.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from voltha_protos import openflow_13_pb2 as voltha__protos_dot_openflow__13__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"voltha_protos/logical_device.proto\x12\x0elogical_device\x1a\x1cgoogle/api/annotations.proto\x1a\x1fvoltha_protos/openflow_13.proto\",\n\rLogicalPortId\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07port_id\x18\x02 \x01(\t\"\xb5\x01\n\x0bLogicalPort\x12\n\n\x02id\x18\x01 \x01(\t\x12\'\n\x08ofp_port\x18\x02 \x01(\x0b\x32\x15.openflow_13.ofp_port\x12\x11\n\tdevice_id\x18\x03 \x01(\t\x12\x16\n\x0e\x64\x65vice_port_no\x18\x04 \x01(\r\x12\x11\n\troot_port\x18\x05 \x01(\x08\x12\x33\n\x0eofp_port_stats\x18\x06 \x01(\x0b\x32\x1b.openflow_13.ofp_port_stats\":\n\x0cLogicalPorts\x12*\n\x05items\x18\x01 \x03(\x0b\x32\x1b.logical_device.LogicalPort\"\xa8\x01\n\rLogicalDevice\x12\n\n\x02id\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x61tapath_id\x18\x02 \x01(\x04\x12#\n\x04\x64\x65sc\x18\x03 \x01(\x0b\x32\x15.openflow_13.ofp_desc\x12\x39\n\x0fswitch_features\x18\x04 \x01(\x0b\x32 .openflow_13.ofp_switch_features\x12\x16\n\x0eroot_device_id\x18\x05 \x01(\t\">\n\x0eLogicalDevices\x12,\n\x05items\x18\x01 \x03(\x0b\x32\x1d.logical_device.LogicalDeviceBe\n\"org.opencord.voltha.logical_deviceB\x0fOFLogicalDeviceZ.github.com/opencord/voltha-protos/v5/go/volthab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'voltha_protos.logical_device_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"org.opencord.voltha.logical_deviceB\017OFLogicalDeviceZ.github.com/opencord/voltha-protos/v5/go/voltha'
  _globals['_LOGICALPORTID']._serialized_start=117
  _globals['_LOGICALPORTID']._serialized_end=161
  _globals['_LOGICALPORT']._serialized_start=164
  _globals['_LOGICALPORT']._serialized_end=345
  _globals['_LOGICALPORTS']._serialized_start=347
  _globals['_LOGICALPORTS']._serialized_end=405
  _globals['_LOGICALDEVICE']._serialized_start=408
  _globals['_LOGICALDEVICE']._serialized_end=576
  _globals['_LOGICALDEVICES']._serialized_start=578
  _globals['_LOGICALDEVICES']._serialized_end=640
# @@protoc_insertion_point(module_scope)
